@@ -978,6 +978,8 @@ class Client(commandServer, encrypt, Desktop):
     def umountPath(self, upath):
         if upath and not self.umountSleepPath(upath):
             return False
+        if os.path.exists(upath):
+            os.rmdir(upath)
         return True
 
     def getDefaultRunlevelDaemons(self):
