@@ -488,6 +488,15 @@ class VariableClClientUserMountData(ReadonlyTableVariable):
         return list(generate())
 
 
+class VariableClClientUserMountUnixPath(ReadonlyVariable):
+    """
+    Путь до подключенного unix ресурса данного пользователя
+    """
+    def get(self):
+        return self.select('cl_client_user_mount_path',
+                            cl_client_user_mount_name='unix', limit=1) or ""
+
+
 class VariableClClientUserMountName(FieldValue, ReadonlyVariable):
     """
     Название удаленного ресурса
